#
# spec file for package bitcoin
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2011-2014  P Rusnak <prusnak@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# typical altcoin changes: name, name_pretty, consensus 0, is_base 0
%define base bitcoin
%define base_pretty Bitcoin
%define name_pretty %{base_pretty}
%define consensus 1
%define is_base 1
Name:           bitcoin
Version:        0.16.3
Release:        lp151.1.59
Summary:        P2P Digital Currency
License:        MIT
Group:          Productivity/Networking/Other
URL:            https://%{name}.org
Source0:        https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{base}d.service
Source2:        %{base}d.firewall
Source3:        %{base}d.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  java-devel
BuildRequires:  lcov
BuildRequires:  libdb-4_8-devel
BuildRequires:  libminiupnpc-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libqrencode)
BuildRequires:  pkgconfig(libzmq)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(protobuf)
BuildRequires:  pkgconfig(python3)
%{?systemd_requires}
%if 0%{?suse_version} > 1315
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel
%endif

%description
%{name_pretty} is a peer-to-peer electronic cash system
that is completely decentralized, without the need for a central server or
trusted parties. Users hold the crypto keys to their own money and
transact directly with each other, with the help of a P2P network to check
for double-spending.

Full transaction history is stored locally at each client. This requires
several GB of space, slowly growing.

%package qt5
Summary:        An end-user Qt5 GUI for the %{name_pretty} crypto-currency
Group:          Development/Libraries/Other
Requires(post): update-desktop-files
Requires(postun): update-desktop-files

%description qt5
%{name_pretty} is a peer-to-peer electronic cash system
that is completely decentralized, without the need for a central server or
trusted parties. Users hold the crypto keys to their own money and
transact directly with each other, with the help of a P2P network to check
for double-spending.

Full transaction history is stored locally at each client. This requires
several GB of space, slowly growing.

This package provides %{name_pretty}-Qt, a GUI for %{name_pretty} based on
Qt.

%package utils
Summary:        An end-user CLI for the %{name_pretty} crypto-currency
Group:          Productivity/Networking/Other

%description utils
%{name_pretty} is a peer-to-peer electronic cash system
that is completely decentralized, without the need for a central server or
trusted parties. Users hold the crypto keys to their own money and
transact directly with each other, with the help of a P2P network to check
for double-spending.

Full transaction history is stored locally at each client. This requires
several GB of space, slowly growing.

This package provides %{name}-cli — a CLI tool to interact with the daemon.

%if %{consensus} == 1
%package -n lib%{name}consensus0
Summary:        %{name_pretty} consensus library
Group:          System/Libraries

%description -n lib%{name}consensus0
The purpose of this library is to make the verification functionality that
is critical to %{name_pretty}’s consensus available to other applications,
e.g. to language bindings such as python-%{name}lib or alternative node
implementations.

%package -n lib%{name}consensus-devel
Summary:        Developmont files for %{name} consensus library
Group:          Development/Languages/C and C++
Requires:       lib%{name}consensus0 = %{version}-%{release}

%description -n lib%{name}consensus-devel
The purpose of this library is to make the verification functionality that
is critical to %{name_pretty}’s consensus available to other applications,
e.g. to language bindings such as python-%{name}lib or alternative node
implementations.

This package contains development files.
%endif

%package -n %{name}d
Summary:        Headless daemon for %{name_pretty} crypto-currency
Group:          Development/Libraries/Other

%description -n %{name}d
%{name_pretty} is a peer-to-peer electronic cash system
that is completely decentralized, without the need for a central server or
trusted parties. Users hold the crypto keys to their own money and
transact directly with each other, with the help of a P2P network to check
for double-spending.

Full transaction history is stored locally at each client. This requires
several GB of space, slowly growing.

This package provides %{name}d, headless %{name} daemon.

%package test
Summary:        Automated tests for %{name} client
Group:          Development/Libraries/Other

%description test
%{name_pretty} is a peer-to-peer electronic cash system
that is completely decentralized, without the need for a central server or
trusted parties. Users hold the crypto keys to their own money and
transact directly with each other, with the help of a P2P network to check
for double-spending.

Full transaction history is stored locally at each client. This requires
several GB of space, slowly growing.

This package provides automated tests for %{name}-qt5 and %{name}d.

%prep
%setup -q
# remove 128 resolution from Icon= line
sed -i s/128// contrib/debian/%{name}-qt.desktop

%build
autoreconf -fiv
export CXXFLAGS="%{optflags} -fPIE -fPIC"
export CFLAGS="%{optflags} -fPIE -fPIC"
export LDFLAGS="-pie"
%configure \
  --with-cli=yes \
  --with-daemon=yes \
  --with-gui=qt5 \
  --with-miniupnpc \
  --with-qrencode \
%if %{consensus} == 0
  --without-libs \
%endif
  --disable-hardening
make %{?_smp_mflags} V=1

%check
make %{?_smp_mflags} check

%install
%make_install

install -Dpm 0644 share/pixmaps/%{base}256.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
install -Dpm 0644 contrib/debian/%{name}-qt.desktop %{buildroot}%{_datadir}/applications/%{name}-qt.desktop
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}-qt.desktop

install -Dpm 0644 doc/man/%{name}d.1 %{buildroot}%{_mandir}/man1/%{name}d.1
install -Dpm 0644 doc/man/%{name}-qt.1 %{buildroot}%{_mandir}/man1/%{name}-qt.1
install -Dpm 0644 contrib/debian/examples/%{name}.conf %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

%if !%{is_base}
sed -i "s/%{base}/%{name}/g" %{SOURCE1}
sed -i "s/%{base}/%{name}/g" %{SOURCE2}
sed -i "s/%{base}/%{name}/g" %{SOURCE3}

sed -i "s/%{base_pretty}/%{name_pretty}/g" %{SOURCE1}
sed -i "s/%{base_pretty}/%{name_pretty}/g" %{SOURCE2}
sed -i "s/%{base_pretty}/%{name_pretty}/g" %{SOURCE3}
%endif

mkdir -p %{buildroot}/%{_localstatedir}/lib/%{name}
install -Dpm 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}d

mkdir %{buildroot}%{_sbindir}
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}d
install -Dpm 0644 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}d.service
install -Dpm 0644 %{SOURCE3} %{buildroot}/%{_tmpfilesdir}/%{name}d.conf

%if %{consensus} == 1
# do not ship these
rm -f %{buildroot}%{_libdir}/lib%{name}consensus.a
rm -f %{buildroot}%{_libdir}/lib%{name}consensus.la
%endif

%post qt5
%desktop_database_post

%postun qt5
%desktop_database_postun

%if %{consensus} == 1
%post -n lib%{name}consensus0 -p /sbin/ldconfig
%postun -n lib%{name}consensus0  -p /sbin/ldconfig
%endif

%pre -n %{name}d
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || useradd -r -g %{name} -d %{_localstatedir}/lib/%{name} -s /sbin/nologin -c "%{name_pretty} daemon" %{name}
%service_add_pre %{name}d.service

%post -n %{name}d
%service_add_post %{name}d.service
%if 0%{?suse_version} <= 1320
systemd-tmpfiles --create %{_tmpfilesdir}/%{name}d.conf >/dev/null 2>&1 || :
%else
%tmpfiles_create %{_tmpfilesdir}/%{name}d.conf
%endif

%preun -n %{name}d
%service_del_preun %{name}d.service

%postun -n %{name}d
%service_del_postun %{name}d.service

%files qt5
%license COPYING
%doc README.md doc/release-notes.md
%{_bindir}/%{name}-qt
%{_datadir}/applications/%{name}-qt.desktop
%{_mandir}/man1/%{name}-qt.1%{?ext_man}
%{_datadir}/pixmaps/%{name}.png

%files utils
%license COPYING
%doc README.md doc/release-notes.md
%{_bindir}/%{name}-cli
%{_bindir}/%{name}-tx
%{_mandir}/man1/bitcoin-cli.1%{?ext_man}
%{_mandir}/man1/bitcoin-tx.1%{?ext_man}

%if %{consensus} == 1
%files -n lib%{name}consensus0
%license COPYING
%doc README.md doc/release-notes.md
%{_libdir}/lib%{name}consensus.so.*

%files -n lib%{name}consensus-devel
%license COPYING
%doc README.md
%{_libdir}/lib%{name}consensus.so
%{_includedir}/%{name}consensus.h
%{_libdir}/pkgconfig/lib%{name}consensus.pc
%endif

%files -n %{name}d
%license COPYING
%doc README.md doc/release-notes.md
%{_mandir}/man1/%{name}d.1%{?ext_man}
%{_bindir}/%{name}d
%dir %attr(700,%{name},%{name}) %{_var}/lib/%{name}
%dir %{_sysconfdir}/%{name}
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}d
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%{_unitdir}/%{name}d.service
%{_sbindir}/rc%{name}d
%{_tmpfilesdir}/%{name}d.conf

%files test
%license COPYING
%doc README.md doc/release-notes.md
%{_bindir}/test_%{name}
%{_bindir}/test_%{name}-qt
%{_bindir}/bench_%{name}

%changelog
* Wed Sep 26 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 0.16.3:
  * For complete list of changes see:
    + release-notes-0.16.3.md
    + release-notes-0.16.2.md
- Resolves bsc#1108992 CVE-2018-17144
* Mon Jun 18 2018 mpluskal@suse.com
- Update to version 0.16.1:
  * For complete list of changes see release-notes-0.16.1.md
* Fri Mar  9 2018 develop7@develop7.info
- Update to version 0.16.0
  * Segwit Wallet
  * BIP173 (Bech32) Address support ("bc1..." addresses)
  * HD-wallets by default
  * Replace-By-Fee by default in GUI
  * Wallets directory configuration (`-walletdir`)
  * Build: Minimum GCC bumped to 4.8.x
  * Support for signalling pruned nodes (BIP159)
  * Performance: SHA256 assembly enabled by default
  * GUI changes
  * RPC changes
- Remove bitcoin-boost_1_66.patch
* Tue Jan  2 2018 jengelh@inai.de
- Trim redundant wording from description.
* Mon Jan  1 2018 mpluskal@suse.com
- Update to version 0.15.1:
  * Network fork safety enhancements
  * Miner block size limiting deprecated
  * GUI settings backed up on reset
  * Duplicate wallets disallowed
  * Debug -minimumchainwork argument added
  * Low-level RPC changes
- Fix building with current boost:
  * bitcoin-boost_1_66.patch
* Mon Oct  9 2017 mpluskal@suse.com
- Update to version 0.15.0.1:
  * Some clients may have crashed at startup because a custom fee
    setting was configured that no longer exists in the GUI
  * Small translation updates
  * update manpages, forgotten in 0.15.0
- Small specfile cleanup
* Tue Sep 12 2017 mpluskal@suse.com
- Update to version 0.15.0
  * For a complete list of changes see provided release-notes
* Mon Jun 19 2017 mpluskal@suse.com
- Update to version 0.14.2
  * For a complete list of changes see provided release-notes
* Wed May 31 2017 mpluskal@suse.com
- Update to version 0.14.1:
  * For a complete list of changes see provided release-notes
- Update unit file
* Tue Mar 14 2017 mpluskal@suse.com
- Update to version 0.14.0:
  * For a complete list of changes see provided release-notes
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Wed Dec 14 2016 mpluskal@suse.com
- Update to version 0.13.1:
  * For a complete list of changes see provided release-notes
* Sun Sep 18 2016 mpluskal@suse.com
- Speedup build/reduce it's memory consumption by using gold linker
* Wed Aug 24 2016 mpluskal@suse.com
- Update to version 0.13.0:
  * For a complete list of changes see provided release-notes
- Drop upstreamed patch:
  * bitcoin_missing_ppc64le_in_ax_boost_base.m4.patch
- Fail build on testsuite failure
* Mon Jun 20 2016 normand@linux.vnet.ibm.com
- put back still need patch for ppc64le
  bitcoin_missing_ppc64le_in_ax_boost_base.m4.patch
  (subset of upstream commit id cf5c786)
* Sat Jun 18 2016 mpluskal@suse.com
- Update test dependencies
- Build with safer ldflags
* Fri May 27 2016 mpluskal@suse.com
- Remove unnecessary build dependencies
* Sat Apr 30 2016 mpluskal@suse.com
- Update to 0.12.1
  * For a complete list of changes see provided release-notes
- Drop no longer needed patch
  * bitcoin_missing_ppc64le_in_ax_boost_base.m4.patch
- Small spec file polishing
* Wed Apr 13 2016 mpluskal@suse.com
- Use pretty name for tarball
- Update describtion in .firewall
* Sun Feb 21 2016 mpluskal@suse.com
- Update to 0.12.0
  * For a complete list of changes see provided release-notes
- Small spec file cleanups
  * remove old obsole/provides
  * move icon handling scriplets to correct subpackage
* Wed Dec  9 2015 mpluskal@suse.com
- Update to 0.11.2
  * no upstream changelog provided
* Fri Nov 13 2015 jimmy@boombatower.com
- Small consistency cleanups.
* Thu Nov 12 2015 jimmy@boombatower.com
- Refactor spec to allow for easy building of altcoins.
  * drop bitcoin-fix-desktop-icon-name.patch
* Sat Oct 31 2015 mpluskal@suse.com
- Update to 0.11.1
* Fri Aug  7 2015 normand@linux.vnet.ibm.com
- new patch for ppc64le build and remove ExcludeArch ppc ppc64
  bitcoin_missing_ppc64le_in_ax_boost_base.m4.patch
* Sun Jul 12 2015 prusnak@opensuse.org
- Update to 0.11.0
* Mon Jun  1 2015 mpluskal@suse.com
- Build as PIC so that building does not fail with recent qt5
- Move autoreconf to %%prep
- Enable verbose build
- Use macro for systemd tmpfiles creation
* Wed May 27 2015 mpluskal@suse.com
- Update to 0.10.2
- Correct desktop file handling scriplets and their dependencies
* Fri May 15 2015 mpluskal@suse.com
- Update to 0.10.1
  * no upstream changelog available
* Mon Feb 16 2015 mpluskal@suse.com
- Update to 0.10.0:
  * Faster synchronization
  * new REST interface
  * RPC Server “Warm-Up” Mode
  * Improved signing security
  * Watch-only wallet support
  * Consensus library
  * Standard script rules relaxed for P2SH addresses
  * New tool bitcoin-tx
  * Mining and relay policy enhancements
  * BIP 66: strict DER encoding for signatures
  * for more details see https://bitcoin.org/en/release/v0.10.0
- New package libbitcoinconsensus
- Rename package bitcoin-cli to bitcoin-tools
- Exclude ppc and ppc64 from being built - bitcoin does not support
  big endian.
* Sat Jan 31 2015 mpluskal@suse.com
- Enable qr support
- Run tests after build
* Tue Oct 28 2014 mpluskal@suse.com
- Add _constraint due to memory consumption of build
- Decrease verbosity of bitcoind
* Thu Oct 23 2014 mpluskal@suse.com
- Enable tests
- Split to multiple packages (bitcoind, bitcoin-qt, bitcoin-cli and bitcoin-test)
- Cleanup spec file
- Add unit file and sude .firewall for bitcoind
- Update to 0.9.3:
  + RPC:
  * Avoid a segfault on getblock if it can?t read a block from disk
  * Add paranoid return value checks in base58
  * Protocol and network code:
  * Don?t poll showmyip.com, it doesn?t exist anymore
  * Add a way to limit deserialized string lengths and use it
  * Add a new checkpoint at block 295,000
  * Increase IsStandard() scriptSig length
  * Avoid querying DNS seeds, if we have open connections
  * Remove a useless millisleep in socket handler
  * Stricter memory limits on CNode
  * Better orphan transaction handling
  * Add -maxorphantx=<n> and -maxorphanblocks=<n> options for control over the maximum orphan transactions and blocks
  + Wallet:
  * Check redeemScript size does not exceed 520 byte limit
  * Ignore (and warn about) too-long redeemScripts while loading wallet
  + GUI:
  * fix ?opens in testnet mode when presented with a BIP-72 link with no fallback?
  * AvailableCoins: acquire cs_main mutex
  * Fix unicode character display on MacOSX
  + Miscellaneous:
  * key.cpp: fail with a friendlier message on missing ssl EC support
  * Remove bignum dependency for scripts
  * Upgrade OpenSSL to 1.0.1i (see https://www.openssl.org/news/secadv_20140806.txt - just to be sure, no critical issues for Bitcoin Core)
  * Upgrade miniupnpc to 1.9.20140701
  * Fix boost detection in build system on some platforms
* Fri Jun 20 2014 prusnak@opensuse.org
- updated to 0.9.2.1
* Sat Apr 12 2014 malcolmlewis@opensuse.org
- Updated to version 0.9.1:
  + Dependency-only update to build against fixed openssl security
    vulnerability (CVE-2014-0160).
- Create new patch bitcoin-fix-desktop-icon-name.patch: Rename
  icon in desktop file to remove size reference.
- Allow to build for QT5.
- Add man pages.
- General spec file clean up.
- Drop bitcoin-desktop.patch.
* Fri Mar 21 2014 prusnak@opensuse.org
- updated to 0.9.0
* Mon Dec  9 2013 prusnak@opensuse.org
- updated to 0.8.6
* Sat Sep 14 2013 prusnak@opensuse.org
- updated to 0.8.5
* Sun Sep  1 2013 prusnak@opensuse.org
- updated to 0.8.4
* Tue Jun 25 2013 prusnak@opensuse.org
- updated to 0.8.3
* Thu May 30 2013 prusnak@opensuse.org
- updated to 0.8.2
* Mon Mar 18 2013 prusnak@opensuse.org
- updated to 0.8.1
* Wed Feb 20 2013 prusnak@opensuse.org
- updated to 0.8.0
* Fri Dec 14 2012 prusnak@opensuse.org
- updated to 0.7.2
* Mon Oct 29 2012 prusnak@opensuse.org
- updated to 0.7.1
* Tue Sep 11 2012 prusnak@opensuse.org
- updated to 0.6.3
* Sat May  5 2012 fisiu@opensuse.org
- updated to 0.6.1
* Mon Apr  2 2012 prusnak@opensuse.org
- updated to 0.6.0
* Sat Mar 17 2012 prusnak@opensuse.org
- updated to 0.5.3
* Thu Jan 19 2012 prusnak@opensuse.org
- updated to 0.5.2
* Thu Dec 22 2011 prusnak@opensuse.org
- updated to 0.5.1
* Thu Nov 24 2011 prusnak@opensuse.org
- created package (version 0.5.0)
